@@ -16,19 +16,19 @@ class LanguageSupportTestCase(TestCase):
 
     def test_parsing_with_unsupported_operator(self):
         """
-        NOTE: The French language currently is missing support for
-        unary_operators. This test will start failing when those are
-        added to the language support.
+        Simulate parsing a string with an unsupported operator in a supported
+        language. Eg. using "invalid" to represent an unsupported unary
+        operator in French.
         """
         with self.assertRaises(mathparse.PostfixTokenEvaluationException) as e:
             mathparse.parse(
-                # Three times the square root of 4
-                'trois fois la racine carrée de 4',
+                # Three times the invalid root of 4
+                'trois fois la invalid carrée de 4',
                 language='FRE',
                 stopwords={'la', 'de'}
             )
 
         self.assertEqual(
             str(e.exception),
-            'Unsupported mathematical term: "racine"'
+            'Unsupported mathematical term: "invalid"'
         )
